Record Class BraintrustApiClient.FunctionInvokeRequest

java.lang.Object
java.lang.Record
dev.braintrust.api.BraintrustApiClient.FunctionInvokeRequest
Enclosing interface:
BraintrustApiClient

public static record BraintrustApiClient.FunctionInvokeRequest(@Nullable Object input, @Nullable String version, @Nullable Object parent) extends Record
Request body for invoking a function. The input field wraps the function arguments.

For remote Python/TypeScript scorers, the scorer handler parameters (input, output, expected, metadata) must be wrapped in the outer input field.

The parent field enables distributed tracing by linking the remote function's spans to the caller's span context. It can be either a base64-encoded SpanComponents string or an object with object_type, object_id, and row_ids.

  • Constructor Details

    • FunctionInvokeRequest

      public FunctionInvokeRequest(@Nullable Object input, @Nullable String version, @Nullable Object parent)
      Creates an instance of a FunctionInvokeRequest record class.
      Parameters:
      input - the value for the input record component
      version - the value for the version record component
      parent - the value for the parent record component
  • Method Details

    • of

      Create a simple invoke request with just input
    • of

      public static BraintrustApiClient.FunctionInvokeRequest of(Object input, @Nullable String version)
      Create a simple invoke request with input and version
    • of

      public static BraintrustApiClient.FunctionInvokeRequest of(Object input, Object output, Object expected, Object metadata, @Nullable String version, @Nullable Object parent)
      Create an invoke request for a scorer with distributed tracing support.
      Parameters:
      input - the input to the task being scored
      output - the output from the task being scored
      expected - the expected output
      metadata - additional metadata
      version - optional function version
      parent - optional parent for distributed tracing - can be a base64-encoded SpanComponents string or a Map with object_type, object_id, and row_ids
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • input

      @Nullable public Object input()
      Returns the value of the input record component.
      Returns:
      the value of the input record component
    • version

      @Nullable public String version()
      Returns the value of the version record component.
      Returns:
      the value of the version record component
    • parent

      @Nullable public Object parent()
      Returns the value of the parent record component.
      Returns:
      the value of the parent record component