Record Class BraintrustOpenApiClient.BtqlQueryResponse

java.lang.Object
java.lang.Record
dev.braintrust.api.BraintrustOpenApiClient.BtqlQueryResponse
Enclosing class:
BraintrustOpenApiClient

public static record BraintrustOpenApiClient.BtqlQueryResponse(List<Map<String,Object>> data, BraintrustOpenApiClient.FreshnessState freshnessState, BraintrustOpenApiClient.RealtimeState realtimeState) extends Record
Response from a POST /btql query.

Freshness is determined by comparing BraintrustOpenApiClient.FreshnessState.lastProcessedXactId() to BraintrustOpenApiClient.FreshnessState.lastConsideredXactId(): when both are non-null and equal, the query has caught up to all ingested data and the result is fresh.

The BraintrustOpenApiClient.RealtimeState.type() field indicates whether realtime indexing is still active ("on") or has timed out ("exhausted_timeout").

  • Constructor Details

  • Method Details

    • isFresh

      public boolean isFresh()
      Returns true when the query result has caught up to all ingested data.
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • data

      public List<Map<String,Object>> data()
      Returns the value of the data record component.
      Returns:
      the value of the data record component
    • freshnessState

      public BraintrustOpenApiClient.FreshnessState freshnessState()
      Returns the value of the freshnessState record component.
      Returns:
      the value of the freshnessState record component
    • realtimeState

      public BraintrustOpenApiClient.RealtimeState realtimeState()
      Returns the value of the realtimeState record component.
      Returns:
      the value of the realtimeState record component