Record Class BraintrustOpenApiClient.FreshnessState

java.lang.Object
java.lang.Record
dev.braintrust.api.BraintrustOpenApiClient.FreshnessState
Enclosing class:
BraintrustOpenApiClient

public static record BraintrustOpenApiClient.FreshnessState(String lastProcessedXactId, String lastConsideredXactId) extends Record
  • Constructor Details

    • FreshnessState

      public FreshnessState(String lastProcessedXactId, String lastConsideredXactId)
      Creates an instance of a FreshnessState record class.
      Parameters:
      lastProcessedXactId - the value for the lastProcessedXactId record component
      lastConsideredXactId - the value for the lastConsideredXactId record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • lastProcessedXactId

      public String lastProcessedXactId()
      Returns the value of the lastProcessedXactId record component.
      Returns:
      the value of the lastProcessedXactId record component
    • lastConsideredXactId

      public String lastConsideredXactId()
      Returns the value of the lastConsideredXactId record component.
      Returns:
      the value of the lastConsideredXactId record component