Record Class TaskResult<INPUT,OUTPUT>

java.lang.Object
java.lang.Record
dev.braintrust.eval.TaskResult<INPUT,OUTPUT>

public record TaskResult<INPUT,OUTPUT>(OUTPUT result, DatasetCase<INPUT,OUTPUT> datasetCase, @Nonnull Parameters parameters) extends Record
Result from a single task run.
  • Constructor Details

    • TaskResult

      public TaskResult(OUTPUT result, DatasetCase<INPUT,OUTPUT> datasetCase)
    • TaskResult

      public TaskResult(OUTPUT result, DatasetCase<INPUT,OUTPUT> datasetCase, @Nonnull Parameters parameters)
      Creates an instance of a TaskResult record class.
      Parameters:
      result - the value for the result record component
      datasetCase - the value for the datasetCase record component
      parameters - the value for the parameters record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • result

      public OUTPUT result()
      Returns the value of the result record component.
      Returns:
      the value of the result record component
    • datasetCase

      public DatasetCase<INPUT,OUTPUT> datasetCase()
      Returns the value of the datasetCase record component.
      Returns:
      the value of the datasetCase record component
    • parameters

      @Nonnull public Parameters parameters()
      Returns the value of the parameters record component.
      Returns:
      the value of the parameters record component