Record Class BraintrustSpanProcessor.ParentContext

java.lang.Object
java.lang.Record
dev.braintrust.trace.BraintrustSpanProcessor.ParentContext
Enclosing class:
BraintrustSpanProcessor

public static record BraintrustSpanProcessor.ParentContext(@Nullable String projectId, @Nullable String experimentId, BraintrustSpanProcessor.ParentContext.ParentType type) extends Record
Parent context for spans (project or experiment).
  • Constructor Details

    • ParentContext

      public ParentContext(@Nullable String projectId, @Nullable String experimentId, BraintrustSpanProcessor.ParentContext.ParentType type)
      Creates an instance of a ParentContext record class.
      Parameters:
      projectId - the value for the projectId record component
      experimentId - the value for the experimentId record component
      type - the value for the type record component
  • Method Details

    • project

      public static BraintrustSpanProcessor.ParentContext project(String projectId)
    • experiment

      public static BraintrustSpanProcessor.ParentContext experiment(String experimentId)
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • projectId

      @Nullable public String projectId()
      Returns the value of the projectId record component.
      Returns:
      the value of the projectId record component
    • experimentId

      @Nullable public String experimentId()
      Returns the value of the experimentId record component.
      Returns:
      the value of the experimentId record component
    • type

      Returns the value of the type record component.
      Returns:
      the value of the type record component