Record Class SpanComponents

java.lang.Object
java.lang.Record
dev.braintrust.trace.SpanComponents

public record SpanComponents(BraintrustUtils.Parent parent, @Nullable SpanComponents.RowIds rowIds) extends Record
Represents span components for distributed tracing in object format.

This is used to pass parent span context when invoking remote functions, enabling the remote function's spans to appear as children of the caller's span in the Braintrust UI.

  • Constructor Details

    • SpanComponents

      public SpanComponents(BraintrustUtils.Parent parent, @Nullable SpanComponents.RowIds rowIds)
      Creates an instance of a SpanComponents record class.
      Parameters:
      parent - the value for the parent record component
      rowIds - the value for the rowIds record component
  • Method Details

    • toMap

      public Map<String,Object> toMap()
      Convert to a Map for JSON serialization.

      The resulting map matches the InvokeParent object format expected by the API.

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • parent

      public BraintrustUtils.Parent parent()
      Returns the value of the parent record component.
      Returns:
      the value of the parent record component
    • rowIds

      @Nullable public SpanComponents.RowIds rowIds()
      Returns the value of the rowIds record component.
      Returns:
      the value of the rowIds record component