Record Class SpanComponents.RowIds

java.lang.Object
java.lang.Record
dev.braintrust.trace.SpanComponents.RowIds
Record Components:
spanId - The OTEL span ID (16 hex characters)
rootSpanId - The OTEL trace ID (32 hex characters)
Enclosing class:
SpanComponents

public static record SpanComponents.RowIds(String spanId, String rootSpanId) extends Record
Row IDs for linking spans within a trace.
  • Constructor Details

    • RowIds

      public RowIds(String spanId, String rootSpanId)
      Creates an instance of a RowIds record class.
      Parameters:
      spanId - the value for the spanId record component
      rootSpanId - the value for the rootSpanId record component
  • Method Details

    • toMap

      public Map<String,Object> toMap()
      Convert to a Map for JSON serialization.
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • spanId

      public String spanId()
      Returns the value of the spanId record component.
      Returns:
      the value of the spanId record component
    • rootSpanId

      public String rootSpanId()
      Returns the value of the rootSpanId record component.
      Returns:
      the value of the rootSpanId record component