Package dev.braintrust.trace
package dev.braintrust.trace
-
ClassDescriptionUtility to serialize LLM attachment data in a braintrust-friendly manner.Provides access to the distributed trace spans for a single eval task stored in Braintrust.Used to identify the braintrust parent for spans and experiments.Custom span processor that enriches spans with Braintrust-specific attributes.Parent context for spans (project or experiment).Main entry point for Braintrust tracing setup.Represents span components for distributed tracing in object format.Row IDs for linking spans within a trace.