Package dev.braintrust.api
Record Class BraintrustApiClient.FunctionInvokeRequest
java.lang.Object
java.lang.Record
dev.braintrust.api.BraintrustApiClient.FunctionInvokeRequest
- Enclosing interface:
- BraintrustApiClient
public static record BraintrustApiClient.FunctionInvokeRequest(@Nullable Object input, @Nullable String version, @Nullable Object parent)
extends Record
Request body for invoking a function. The input field wraps the function arguments.
For remote Python/TypeScript scorers, the scorer handler parameters (input, output, expected, metadata) must be wrapped in the outer input field.
The parent field enables distributed tracing by linking the remote function's spans to the caller's span context. It can be either a base64-encoded SpanComponents string or an object with object_type, object_id, and row_ids.
-
Constructor Summary
ConstructorsConstructorDescriptionFunctionInvokeRequest(Object input, String version, Object parent) Creates an instance of aFunctionInvokeRequestrecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.input()Returns the value of theinputrecord component.Create a simple invoke request with just inputCreate an invoke request for a scorer with distributed tracing support.Create a simple invoke request with input and versionparent()Returns the value of theparentrecord component.final StringtoString()Returns a string representation of this record class.version()Returns the value of theversionrecord component.
-
Constructor Details
-
FunctionInvokeRequest
public FunctionInvokeRequest(@Nullable Object input, @Nullable String version, @Nullable Object parent) Creates an instance of aFunctionInvokeRequestrecord class.- Parameters:
input- the value for theinputrecord componentversion- the value for theversionrecord componentparent- the value for theparentrecord component
-
-
Method Details
-
of
Create a simple invoke request with just input -
of
Create a simple invoke request with input and version -
of
public static BraintrustApiClient.FunctionInvokeRequest of(Object input, Object output, Object expected, Object metadata, @Nullable String version, @Nullable Object parent) Create an invoke request for a scorer with distributed tracing support.- Parameters:
input- the input to the task being scoredoutput- the output from the task being scoredexpected- the expected outputmetadata- additional metadataversion- optional function versionparent- optional parent for distributed tracing - can be a base64-encoded SpanComponents string or a Map with object_type, object_id, and row_ids
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
input
Returns the value of theinputrecord component.- Returns:
- the value of the
inputrecord component
-
version
Returns the value of theversionrecord component.- Returns:
- the value of the
versionrecord component
-
parent
Returns the value of theparentrecord component.- Returns:
- the value of the
parentrecord component
-