Package dev.braintrust.api
Class BraintrustOpenApiClient
java.lang.Object
dev.braintrust.openapi.ApiClient
dev.braintrust.api.BraintrustOpenApiClient
public class BraintrustOpenApiClient
extends dev.braintrust.openapi.ApiClient
Provides the necessary API calls for the Braintrust SDK. Users of the SDK should favor using
Eval or BraintrustTracing-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final recordResponse from aPOST /btqlquery.static final recordstatic final recordstatic final recordstatic final recordReal-time indexing state for a BTQL query. -
Field Summary
Fields inherited from class dev.braintrust.openapi.ApiClient
asyncResponseInterceptor, basePath, builder, connectTimeout, host, interceptor, mapper, port, readTimeout, responseInterceptor, scheme -
Method Summary
Modifier and TypeMethodDescriptionCallsPOST /btqlto run an arbitrary BTQL query.dev.braintrust.openapi.model.ProjectfetchOrCreateProject(BraintrustConfig config) dev.braintrust.openapi.model.ProjectfetchOrCreateProject(String projectId, String projectName) fetchOrgInfo(String orgId) Look up or create the project from config, resolve the org name via login, and return the Braintrust app URI for the project.login()CallsPOST /api/apikey/loginto retrieve organization info for the current API key.static BraintrustOpenApiClientof(BraintrustConfig config) Methods inherited from class dev.braintrust.openapi.ApiClient
createDefaultHttpClientBuilder, createDefaultObjectMapper, getAsyncResponseInterceptor, getBaseUri, getConnectTimeout, getDefaultBaseUri, getHttpClient, getObjectMapper, getReadTimeout, getRequestInterceptor, getResponseInterceptor, parameterToPairs, parameterToPairs, setAsyncResponseInterceptor, setBasePath, setConnectTimeout, setHost, setHttpClientBuilder, setObjectMapper, setPort, setReadTimeout, setRequestInterceptor, setResponseInterceptor, setScheme, updateBaseUri, urlEncode, valueToString
-
Method Details
-
of
-
login
CallsPOST /api/apikey/loginto retrieve organization info for the current API key. This endpoint is not in the OpenAPI spec so it is implemented here as a custom method. -
fetchProjectUri
Look up or create the project from config, resolve the org name via login, and return the Braintrust app URI for the project. -
fetchOrgInfo
-
fetchOrCreateProject
-
fetchOrCreateProject
-
btqlQuery
CallsPOST /btqlto run an arbitrary BTQL query. This endpoint is not in the OpenAPI spec so it is implemented here as a custom method.
-