Package dev.braintrust.api
Record Class BraintrustOpenApiClient.FreshnessState
java.lang.Object
java.lang.Record
dev.braintrust.api.BraintrustOpenApiClient.FreshnessState
- Enclosing class:
- BraintrustOpenApiClient
-
Constructor Summary
ConstructorsConstructorDescriptionFreshnessState(String lastProcessedXactId, String lastConsideredXactId) Creates an instance of aFreshnessStaterecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of thelastConsideredXactIdrecord component.Returns the value of thelastProcessedXactIdrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
FreshnessState
Creates an instance of aFreshnessStaterecord class.- Parameters:
lastProcessedXactId- the value for thelastProcessedXactIdrecord componentlastConsideredXactId- the value for thelastConsideredXactIdrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
lastProcessedXactId
Returns the value of thelastProcessedXactIdrecord component.- Returns:
- the value of the
lastProcessedXactIdrecord component
-
lastConsideredXactId
Returns the value of thelastConsideredXactIdrecord component.- Returns:
- the value of the
lastConsideredXactIdrecord component
-