Interface Scorer<INPUT,OUTPUT>

Type Parameters:
INPUT - type of the input data
OUTPUT - type of the output data
All Known Subinterfaces:
TracedScorer<INPUT,OUTPUT>
All Known Implementing Classes:
ScorerBrainstoreImpl

public interface Scorer<INPUT,OUTPUT>
A scorer evaluates the result of a task against a dataset case, producing a score between 0 (inclusive) and 1 (inclusive).