Package dev.braintrust.eval
package dev.braintrust.eval
-
ClassDescriptionA single structured classification produced by a
Classifier.Classifier<INPUT,OUTPUT> A classifier categorizes and labels eval outputs, producing zero or more structuredClassificationitems.Dataset<INPUT,OUTPUT> Datasets define the cases for evals.Dataset.Cursor<CASE>DatasetBrainstoreImpl<INPUT,OUTPUT> A dataset loaded externally from Braintrust using paginated API fetchesDatasetCase<INPUT,OUTPUT> A single row in a dataset.Eval<INPUT,OUTPUT> An evaluation framework for testing AI models.Eval.Builder<INPUT,OUTPUT> Builder for creating evaluations with fluent API.EvalCase<INPUT,OUTPUT> Deprecated.Results of all eval cases of an experiment.ParameterDef<T>Definition of a named parameter that can be configured from the Braintrust Playground UI.Holds the merged parameter values for a single eval run, along with the parameter definitions.Individual metric value assigned by a scorer.Scorer<INPUT,OUTPUT> A scorer evaluates the result of a task against a dataset case, producing a score between 0 (inclusive) and 1 (inclusive).ScorerBrainstoreImpl<INPUT,OUTPUT> A scorer that invokes a remote Braintrust function to compute scores.Task<INPUT,OUTPUT> A task function that runs against a single dataset case and produces an output.TaskResult<INPUT,OUTPUT> Result from a single task run.TracedClassifier<INPUT,OUTPUT> A classifier that receives access to the full distributed trace of the task that was evaluated.TracedScorer<INPUT,OUTPUT> A scorer that receives access to the full distributed trace of the task that was evaluated.