Package dev.braintrust.trace
Record Class SpanComponents.RowIds
java.lang.Object
java.lang.Record
dev.braintrust.trace.SpanComponents.RowIds
- Record Components:
spanId- The OTEL span ID (16 hex characters)rootSpanId- The OTEL trace ID (32 hex characters)
- Enclosing class:
- SpanComponents
Row IDs for linking spans within a trace.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of therootSpanIdrecord component.spanId()Returns the value of thespanIdrecord component.toMap()Convert to a Map for JSON serialization.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
RowIds
Creates an instance of aRowIdsrecord class.- Parameters:
spanId- the value for thespanIdrecord componentrootSpanId- the value for therootSpanIdrecord component
-
-
Method Details
-
toMap
Convert to a Map for JSON serialization. -
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
spanId
Returns the value of thespanIdrecord component.- Returns:
- the value of the
spanIdrecord component
-
rootSpanId
Returns the value of therootSpanIdrecord component.- Returns:
- the value of the
rootSpanIdrecord component
-